import * as Ajv from 'ajv';
import Ajv__default from 'ajv';

declare const ajv: Ajv__default.Ajv;
type ajvErrors = Ajv.ErrorObject[];
/**
 * Validate Schema itself (metaSchema)
 * Validates against contents of the `$schema` field
 * @link https://github.com/epoberezkin/ajv#validateschemaobject-schema---boolean
 */
declare function validateSchema(schema: Record<string, unknown>): {
    ok: boolean;
    message: string;
};
/**
 * Validate Schema and Assign Defaults
 * Any `default` on properties will be added if that property is absent
 * @link https://github.com/epoberezkin/ajv#assigning-defaults
 */
declare function validateSchemaAndAssignDefaults<T>(schema: Record<string, unknown>, data: T): {
    ok: boolean;
    message: string;
    data: T;
};
/**
 * Validate Data against Schema
 * @link https://github.com/epoberezkin/ajv
 */
declare function validateDataAgainstSchema<T>(schema: Record<string, unknown>, data: T): {
    ok: boolean;
    message: string;
    errors?: ajvErrors;
};

export { ajv, validateDataAgainstSchema, validateSchema, validateSchemaAndAssignDefaults };
